@@ -1,19 +1,31 @@
-from django.views.generic.edit import FormView
-from django.views.generic.base import TemplateView
-from django.core.urlresolvers import reverse_lazy
+from django.conf import settings
 from django.contrib.auth import get_user_model
 from django.contrib.sites.models import get_current_site
+from django.core.urlresolvers import reverse_lazy
 from django.shortcuts import redirect
+from django.views.generic.base import TemplateView
+from django.views.generic.edit import FormView
 
-from .models import Validation, SIGNUP_FORM_CLASS
+from .models import Validation
 
 class SignUpView(FormView):
 	template_name = 'registration/signup_form.html'
 	success_url = reverse_lazy('signup_signup_complete')
 
+	def dispatch(self, request, *args, **kwargs):
+		if not settings.SIGNUP_ALLOWED:
+			return redirect('signup_closed')
+
+		if request.method.lower() in self.http_method_names:
+			handler = getattr(
+				self, request.method.lower(), self.http_method_not_allowed)
+		else:
+			handler = self.http_method_not_allowed
+		return handler(request, *args, **kwargs)
+
 	def get_form_class(self):
 		if self.form_class is None:
-			form_class_name = SIGNUP_FORM_CLASS
+			form_class_name = settings.SIGNUP_FORM_CLASS
 			if form_class_name is None:
 				from .forms import DefaultUserCreationForm
 				self.form_class = DefaultUserCreationForm
@@ -33,6 +45,8 @@ class SignUpView(FormView):
 
 		return super(SignUpView, self).form_valid(form)
 
+class SignupClosedView(TemplateView):
+	template_name = 'registration/signup_closed.html'
 		
 class SignUpCompleteView(TemplateView):
 	template_name = 'registration/signup_complete.html'
